pydevDAG._structure._pyudev._graphs module — pydevDAG 1.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- pydevDAG 1.0 documentation »
- pydevDAG »
- pydevDAG package »
- pydevDAG._structure package »
- pydevDAG._structure._pyudev package »

# pydevDAG._structure._pyudev._graphs module

## pydevDAG._structure._pyudev._graphs

Individual graph classes.

class `pydevDAG._structure._pyudev._graphs.` `DMPartitionGraphs`

  Bases: `pydevDAG._structure._pyudev._types.PyudevGraph`

  Build graphs of relationships between device mapper devices and partitions.

  classmethod `complete`(context, **kwargs)
  static `congruence_graph`(context, device)

    Build a graph of congruence relation between device mapper devices and partition devices.

    Parameters: | context (Context) – a udev context device (Device) – the partition device
    Returns: | a graph
    Return type: | DiGraph

class `pydevDAG._structure._pyudev._graphs.` `EnclosureGraphs`

  Bases: `pydevDAG._structure._pyudev._types.PyudevGraph`

  Graph from enclosure to enclosed device.

  classmethod `complete`(context, **kwargs)

class `pydevDAG._structure._pyudev._graphs.` `PartitionGraphs`

  Bases: `pydevDAG._structure._pyudev._types.PyudevGraph`

  Build graphs of partition relationships.

  classmethod `complete`(context, **kwargs)
  static `partition_graph`(device)

    Make a graph of partition relationships.

    Parameters: | device (Device) – the partition device
    Returns: | a graph
    Return type: | DiGraph

class `pydevDAG._structure._pyudev._graphs.` `PyudevGraphs`

  Bases: `object`

  Classes that build pyudev based graphs.

  classmethod `CLASSES`()

    All classes that implement PyudevGraph.

  `DM_PARTITION_GRAPHS`

    alias of `DMPartitionGraphs`

  `ENCLOSURE_GRAPHS`

    alias of `EnclosureGraphs`

  `PARTITION_GRAPHS`

    alias of `PartitionGraphs`

  `SPINDLE_GRAPHS`

    alias of `SpindleGraphs`

  `SYSFS_BLOCK_GRAPHS`

    alias of `SysfsBlockGraphs`

  `SYSFS_GRAPHS`

    alias of `SysfsGraphs`

class `pydevDAG._structure._pyudev._graphs.` `SpindleGraphs`

  Bases: `pydevDAG._structure._pyudev._types.PyudevGraph`

  Build graphs of relationships with actual physical disks.

  classmethod `complete`(context, **kwargs)
  static `spindle_graph`(device)

    Make a graph of spindle relationships.

    Parameters: | device (Device) – the partition device
    Returns: | a graph
    Return type: | DiGraph

class `pydevDAG._structure._pyudev._graphs.` `SysfsBlockGraphs`

  Bases: `pydevDAG._structure._pyudev._types.PyudevGraph`

  Composes holders/slaves graphs for block devices.

  classmethod `complete`(context, **kwargs)

class `pydevDAG._structure._pyudev._graphs.` `SysfsGraphs`

  Bases: `pydevDAG._structure._pyudev._types.PyudevGraph`

  Build sysfs graphs in various ways.

  classmethod `complete`(context, **kwargs)
  classmethod `parents_and_children`(context, device)

    Make a graph of the parents and children of a device.

    Parameters: | context (Context) – the libudev context device (Device) – the device
    Returns: | a graph
    Return type: | DiGraph

  static `slaves_and_holders`(context, device, recursive=True)

    Make a graph of slaves and holders of a device.

    Parameters: | context (Context) – the libudev context device (Device) – the device recursive (bool) – True for recursive, False otherwise
    Returns: | a graph
    Return type: | DiGraph

### Navigation

- index
- modules |
- next |
- previous |
- pydevDAG 1.0 documentation »
- pydevDAG »
- pydevDAG package »
- pydevDAG._structure package »
- pydevDAG._structure._pyudev package »